This is an automated email from the ASF dual-hosted git repository.

nkak pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/madlib.git


The following commit(s) were added to refs/heads/master by this push:
     new d98e7a6  Typos
d98e7a6 is described below

commit d98e7a614ed785f22acc132cd8f076f29bcce493
Author: Bruno P. Kinoshita <bruno.kinosh...@niwa.co.nz>
AuthorDate: Fri Jan 11 10:36:49 2019 +1300

    Typos
---
 src/dbal/BoostIntegration/Assertions_impl.hpp                       | 2 +-
 src/dbal/DynamicStruct_impl.hpp                                     | 2 +-
 src/dbal/DynamicStruct_proto.hpp                                    | 2 +-
 .../SymmetricPositiveDefiniteEigenDecomposition_impl.hpp            | 2 +-
 src/dbal/OutputStreamBufferBase_impl.hpp                            | 2 +-
 src/madpack/create_changelist.py                                    | 2 +-
 src/madpack/madpack.py                                              | 4 ++--
 src/madpack/utilities.py                                            | 2 +-
 src/modules/assoc_rules/assoc_rules.cpp                             | 2 +-
 src/modules/convex/linear_svm_igd.cpp                               | 2 +-
 src/modules/convex/lmf_igd.cpp                                      | 4 ++--
 src/modules/convex/mlp_igd.cpp                                      | 4 ++--
 src/modules/convex/newton.hpp                                       | 4 ++--
 src/modules/regress/logistic.cpp                                    | 4 ++--
 src/modules/regress/mlogr_margins.cpp                               | 2 +-
 src/modules/regress/multilogistic.cpp                               | 4 ++--
 src/modules/stats/cox_prop_hazards.cpp                              | 2 +-
 src/modules/stats/coxph_improved.cpp                                | 6 +++---
 src/modules/stats/robust_variance_coxph.cpp                         | 6 +++---
 19 files changed, 29 insertions(+), 29 deletions(-)

diff --git a/src/dbal/BoostIntegration/Assertions_impl.hpp 
b/src/dbal/BoostIntegration/Assertions_impl.hpp
index aa8502f..30fe74d 100644
--- a/src/dbal/BoostIntegration/Assertions_impl.hpp
+++ b/src/dbal/BoostIntegration/Assertions_impl.hpp
@@ -54,7 +54,7 @@ void
 assertion_failed(char const *inExpr, char const *inFunction,
     char const *inFile, long inLine) {
 
-    assertion_failed_msg("A run-time error occured.", inExpr, inFunction,
+    assertion_failed_msg("A run-time error occurred.", inExpr, inFunction,
         inFile, inLine);
 }
 
diff --git a/src/dbal/DynamicStruct_impl.hpp b/src/dbal/DynamicStruct_impl.hpp
index 281840d..978f138 100644
--- a/src/dbal/DynamicStruct_impl.hpp
+++ b/src/dbal/DynamicStruct_impl.hpp
@@ -196,7 +196,7 @@ DynamicStructBase<Derived,
     if (mByteStream.eof()) {
         // The assumption is that either
         // a) we have a valid dynamic struct, in which case we do not end here
-        // b) we have an unintialized dynamic struct, which only consists of
+        // b) we have an uninitialized dynamic struct, which only consists of
         //    (too few) zero bytes.
         // If (b) is violated, then mByteStream.tell() might not have the
         // correct size information.
diff --git a/src/dbal/DynamicStruct_proto.hpp b/src/dbal/DynamicStruct_proto.hpp
index 8fe810e..55b710a 100644
--- a/src/dbal/DynamicStruct_proto.hpp
+++ b/src/dbal/DynamicStruct_proto.hpp
@@ -150,7 +150,7 @@ public:
      * @brief Bind a DynamicStruct object to the current position in the stream
      *
      * The following idiom (in-class friend function together with static
-     * polymorphicsm) is called the "Barton-Nackman trick". Essentially, we 
only
+     * polymorphism) is called the "Barton-Nackman trick". Essentially, we only
      * make operator>> visible if type Derived is involved.
      *
      * Subclasses have to implement the bind() function.
diff --git 
a/src/dbal/EigenIntegration/SymmetricPositiveDefiniteEigenDecomposition_impl.hpp
 
b/src/dbal/EigenIntegration/SymmetricPositiveDefiniteEigenDecomposition_impl.hpp
index 09a4a2c..d5ab882 100644
--- 
a/src/dbal/EigenIntegration/SymmetricPositiveDefiniteEigenDecomposition_impl.hpp
+++ 
b/src/dbal/EigenIntegration/SymmetricPositiveDefiniteEigenDecomposition_impl.hpp
@@ -56,7 +56,7 @@ 
SymmetricPositiveDefiniteEigenDecomposition<MatrixType>::conditionNo()
     // All eigenvalues of a positive semi-definite matrix are
     // non-negative, so in theory no need to take absolute values.
     // Unfortunately, numerical instabilities can cause eigenvalues to
-    // be slightly negative. We should interprete that as 0.
+    // be slightly negative. We should interpret that as 0.
     if (denominator < 0)
         denominator = 0;
 
diff --git a/src/dbal/OutputStreamBufferBase_impl.hpp 
b/src/dbal/OutputStreamBufferBase_impl.hpp
index 4ee7dcd..a1c3733 100644
--- a/src/dbal/OutputStreamBufferBase_impl.hpp
+++ b/src/dbal/OutputStreamBufferBase_impl.hpp
@@ -33,7 +33,7 @@ OutputStreamBufferBase<Derived, C, 
Allocator>::~OutputStreamBufferBase() {
  * @brief Output a string
  *
  * Subclasses are required to implement this method and to feed the message
- * the the the DBMS-specific logging routine.
+ * to the DBMS-specific logging routine.
  * @param inMsg Null-terminated string to be output.
  * @param inLength Length of inMsg (for convenience).
  */
diff --git a/src/madpack/create_changelist.py b/src/madpack/create_changelist.py
index a88b71d..74bea42 100644
--- a/src/madpack/create_changelist.py
+++ b/src/madpack/create_changelist.py
@@ -28,7 +28,7 @@
 
 # Usage (must be executed in the src/madpack directory):
 # python create_changelist.py <database name> <old version branch> <new 
version branch> <changelist filename>
-# If you are using the master branch, plase make sure to edit the branch/tag 
in the output file
+# If you are using the master branch, please make sure to edit the branch/tag 
in the output file
 
 # Example (should be equivalent to changelist_1.13_1.14.yaml):
 # python create_changelist.py madlib rel/v1.13 rel/v1.14 chtest1.yaml
diff --git a/src/madpack/madpack.py b/src/madpack/madpack.py
index ac498d1..6c191ca 100755
--- a/src/madpack/madpack.py
+++ b/src/madpack/madpack.py
@@ -719,7 +719,7 @@ def _execute_per_module_db_create_obj_algo(schema, 
maddir_mod_py, module,
                                            sqlfile, algoname, cur_tmpdir,
                                            upgrade, create_obj_handle, sc):
     """
-        Perform opertions that have to be done per module when
+        Perform operations that have to be done per module when
         _db_create_objects function is invoked
     """
     if not upgrade:
@@ -936,7 +936,7 @@ def parse_arguments():
         '-c', '--conn', metavar='CONNSTR', nargs=1, dest='connstr', 
default=None,
         help="""Connection string of the following syntax:
                    [user[/password]@][host][:port][/database]
-                 If not provided default values will be derived for PostgerSQL 
and Greenplum:
+                 If not provided default values will be derived for PostgreSQL 
and Greenplum:
                  - user: PGUSER or USER env variable or OS username
                  - pass: PGPASSWORD env variable or runtime prompt
                  - host: PGHOST env variable or 'localhost'
diff --git a/src/madpack/utilities.py b/src/madpack/utilities.py
index 94fc1d5..9e4e95b 100644
--- a/src/madpack/utilities.py
+++ b/src/madpack/utilities.py
@@ -145,7 +145,7 @@ def run_query(sql, con_args, show_error=True):
 def get_db_madlib_version(con_args, schema):
     """
     Read MADlib version from database
-        @param con_args database conection object
+        @param con_args database connection object
         @param schema MADlib schema name
     """
     try:
diff --git a/src/modules/assoc_rules/assoc_rules.cpp 
b/src/modules/assoc_rules/assoc_rules.cpp
index 560e848..85d0046 100644
--- a/src/modules/assoc_rules/assoc_rules.cpp
+++ b/src/modules/assoc_rules/assoc_rules.cpp
@@ -92,7 +92,7 @@ gen_rules_from_cfp::SRF_next(void *user_fctx, bool 
*is_last_call) {
     int                 len = 0;
 
     if (!is_last_call)
-        throw std::invalid_argument("the paramter is_last_class should not be 
null");
+        throw std::invalid_argument("the parameter is_last_class should not be 
null");
 
     if (myfctx->num_calls <= 0) {
         *is_last_call = true;
diff --git a/src/modules/convex/linear_svm_igd.cpp 
b/src/modules/convex/linear_svm_igd.cpp
index 79dc496..f01a2e2 100644
--- a/src/modules/convex/linear_svm_igd.cpp
+++ b/src/modules/convex/linear_svm_igd.cpp
@@ -121,7 +121,7 @@ linear_svm_igd_transition::run(AnyType &args) {
 }
 
 /**
- * @brief Perform the perliminary aggregation function: Merge transition states
+ * @brief Perform the preliminary aggregation function: Merge transition states
  */
 AnyType
 linear_svm_igd_merge::run(AnyType &args) {
diff --git a/src/modules/convex/lmf_igd.cpp b/src/modules/convex/lmf_igd.cpp
index 039052d..c96f987 100644
--- a/src/modules/convex/lmf_igd.cpp
+++ b/src/modules/convex/lmf_igd.cpp
@@ -45,7 +45,7 @@ lmf_igd_transition::run(AnyType &args) {
     // For other tuples: args[0] holds the computation state until last tuple
     LMFIGDState<MutableArrayHandle<double> > state = args[0];
 
-    // initilize the state if first tuple
+    // initialize the state if first tuple
     if (state.algo.numRows == 0) {
         if (!args[4].isNull()) {
             LMFIGDState<ArrayHandle<double> > previousState = args[4];
@@ -111,7 +111,7 @@ lmf_igd_transition::run(AnyType &args) {
 }
 
 /**
- * @brief Perform the perliminary aggregation function: Merge transition states
+ * @brief Perform the preliminary aggregation function: Merge transition states
  */
 AnyType
 lmf_igd_merge::run(AnyType &args) {
diff --git a/src/modules/convex/mlp_igd.cpp b/src/modules/convex/mlp_igd.cpp
index 0fb17b3..599170b 100644
--- a/src/modules/convex/mlp_igd.cpp
+++ b/src/modules/convex/mlp_igd.cpp
@@ -140,7 +140,7 @@ mlp_igd_transition::run(AnyType &args) {
 }
 
 /**
- * @brief Perform the perliminary aggregation function: Merge transition states
+ * @brief Perform the preliminary aggregation function: Merge transition states
  */
 AnyType
 mlp_igd_merge::run(AnyType &args) {
@@ -189,7 +189,7 @@ mlp_minibatch_transition::run(AnyType &args) {
     // For other tuples: args[0] holds the computation state until last tuple
     MLPMiniBatchState<MutableArrayHandle<double> > state = args[0];
 
-    // initilize the state if first tuple
+    // initialize the state if first tuple
     if (state.numRows == 0) {
         if (!args[3].isNull()) {
             MLPMiniBatchState<ArrayHandle<double> > previousState = args[3];
diff --git a/src/modules/convex/newton.hpp b/src/modules/convex/newton.hpp
index a4a8c84..94773cd 100644
--- a/src/modules/convex/newton.hpp
+++ b/src/modules/convex/newton.hpp
@@ -2,8 +2,8 @@
  *
  * @file newton.hpp
  *
- * Generic implementaion of Newton's method, in the fashion of
- * user-definied aggregates. They should be called by actually database
+ * Generic implementation of Newton's method, in the fashion of
+ * user-defined aggregates. They should be called by actually database
  * functions, after arguments are properly parsed.
  *
  *//* ----------------------------------------------------------------------- 
*/
diff --git a/src/modules/regress/mlogr_margins.cpp 
b/src/modules/regress/mlogr_margins.cpp
index 2b8b8fd..627a18b 100644
--- a/src/modules/regress/mlogr_margins.cpp
+++ b/src/modules/regress/mlogr_margins.cpp
@@ -419,7 +419,7 @@ mlogregr_marginal_step_final::run(AnyType &args) {
     // matrices. We extend the check also to the dependent variables.
     if (!state.X_transp_AX.is_finite())
         throw NoSolutionFoundException("Over- or underflow in intermediate "
-                                       "calulation. Input data is likely of 
poor numerical condition.");
+                                       "calculation. Input data is likely of 
poor numerical condition.");
 
     // Include marginal effects of reference variable:
     // FIXME: They have been taken out of the output for now
diff --git a/src/modules/regress/multilogistic.cpp 
b/src/modules/regress/multilogistic.cpp
index bdcd9a8..4e44d3e 100755
--- a/src/modules/regress/multilogistic.cpp
+++ b/src/modules/regress/multilogistic.cpp
@@ -528,7 +528,7 @@ __mlogregr_irls_step_final::run(AnyType &args) {
     // matrices. We extend the check also to the dependent variables.
     if (!state.X_transp_AX.is_finite() || !state.gradient.is_finite())
         throw NoSolutionFoundException("Over- or underflow in intermediate "
-            "calulation. Input data is likely of poor numerical condition.");
+            "calculation. Input data is likely of poor numerical condition.");
 
     SymmetricPositiveDefiniteEigenDecomposition<Matrix> decomposition(
         -1 * state.X_transp_AX, EigenvaluesOnly, ComputePseudoInverse);
@@ -856,7 +856,7 @@ mlogregr_robust_step_final::run(AnyType &args) {
     // matrices. We extend the check also to the dependent variables.
     if (!state.X_transp_AX.is_finite())
         throw NoSolutionFoundException("Over- or underflow in intermediate "
-            "calulation. Input data is likely of poor numerical condition.");
+            "calculation. Input data is likely of poor numerical condition.");
 
 
     SymmetricPositiveDefiniteEigenDecomposition<Matrix> decomposition(
diff --git a/src/modules/stats/cox_prop_hazards.cpp 
b/src/modules/stats/cox_prop_hazards.cpp
index 792b3c6..cf8deb7 100644
--- a/src/modules/stats/cox_prop_hazards.cpp
+++ b/src/modules/stats/cox_prop_hazards.cpp
@@ -54,7 +54,7 @@ AnyType coxph_step_inner_final::run(AnyType &args) {
 
     if (!state.hessian.is_finite() || !state.grad.is_finite())
         throw NoSolutionFoundException("Over- or underflow in intermediate "
-                                       "calulation. Input data is likely of 
poor numerical condition.");
+                                       "calculation. Input data is likely of 
poor numerical condition.");
 
     // First merge all tied times of death for the last row
     state.grad -= state.multiplier*state.H/state.S;
diff --git a/src/modules/stats/coxph_improved.cpp 
b/src/modules/stats/coxph_improved.cpp
index 11ca283..38624c9 100644
--- a/src/modules/stats/coxph_improved.cpp
+++ b/src/modules/stats/coxph_improved.cpp
@@ -284,7 +284,7 @@ AnyType coxph_improved_step_final::run(AnyType& args)
 
     if (!state.hessian.is_finite() || !state.grad.is_finite())
         throw NoSolutionFoundException("Over- or underflow in intermediate "
-                                       "calulation. Input data is likely of 
poor numerical condition.");
+                                       "calculation. Input data is likely of 
poor numerical condition.");
 
    // First merge all tied times of death for the last row
     state.grad -= state.multiplier*state.H/state.S;
@@ -294,7 +294,7 @@ AnyType coxph_improved_step_final::run(AnyType& args)
 
     if (isinf(static_cast<double>(state.logLikelihood)) || 
isnan(static_cast<double>(state.logLikelihood)))
         throw NoSolutionFoundException("Over- or underflow in intermediate "
-                                       "calulation. Input data is likely of 
poor numerical condition.");
+                                       "calculation. Input data is likely of 
poor numerical condition.");
 
     // Computing pseudo inverse of a PSD matrix
     SymmetricPositiveDefiniteEigenDecomposition<Matrix> decomposition(
@@ -339,7 +339,7 @@ AnyType coxph_improved_strata_step_final::run(AnyType& args)
 
     if (!state.hessian.is_finite() || !state.grad.is_finite())
         throw NoSolutionFoundException("Over- or underflow in intermediate "
-                                       "calulation. Input data is likely of 
poor numerical condition.");
+                                       "calculation. Input data is likely of 
poor numerical condition.");
 
     // Computing pseudo inverse of a PSD matrix
     SymmetricPositiveDefiniteEigenDecomposition<Matrix> decomposition(
diff --git a/src/modules/stats/robust_variance_coxph.cpp 
b/src/modules/stats/robust_variance_coxph.cpp
index 91f6c92..00e26a7 100644
--- a/src/modules/stats/robust_variance_coxph.cpp
+++ b/src/modules/stats/robust_variance_coxph.cpp
@@ -243,7 +243,7 @@ AnyType rb_coxph_step_final::run(AnyType& args)
 
     if (!state.M.is_finite())
         throw NoSolutionFoundException("Over- or underflow in intermediate "
-                                       "calulation. Input data is likely of 
poor numerical condition.");
+                                       "calculation. Input data is likely of 
poor numerical condition.");
 
     // Computing pseudo inverse of a PSD matrix
     SymmetricPositiveDefiniteEigenDecomposition<Matrix> decomposition(
@@ -434,7 +434,7 @@ AnyType rb_coxph_strata_step_final::run(AnyType& args)
 
     if (!state.M.is_finite())
         throw NoSolutionFoundException("Over- or underflow in intermediate "
-                                       "calulation. Input data is likely of 
poor numerical condition.");
+                                       "calculation. Input data is likely of 
poor numerical condition.");
 
     // For the last tie
     state.M = state.M - (state.tie12 + trans(state.tie12)) * state.A
@@ -468,7 +468,7 @@ AnyType rb_sum_strata_final::run(AnyType& args)
 
     if (!state.M.is_finite())
         throw NoSolutionFoundException("Over- or underflow in intermediate "
-                                       "calulation. Input data is likely of 
poor numerical condition.");
+                                       "calculation. Input data is likely of 
poor numerical condition.");
 
     // Computing pseudo inverse of a PSD matrix
     SymmetricPositiveDefiniteEigenDecomposition<Matrix> decomposition(

Reply via email to
diff --git a/src/modules/regress/logistic.cpp b/src/modules/regress/logistic.cpp
index 31007ef..cea0f42 100644
--- a/src/modules/regress/logistic.cpp
+++ b/src/modules/regress/logistic.cpp
@@ -655,9 +655,9 @@ AnyType logregr_irls_step_final::run(AnyType &args) {
     // matrices. We extend the check also to the dependent variables.
     if (!state.X_transp_AX.is_finite() || !state.X_transp_Az.is_finite()){
         //throw NoSolutionFoundException(
         //    "Over- or underflow in intermediate calulation. Input data is "
         //    "likely of poor numerical condition.");
-        warning("Over- or underflow in intermediate calulation. Input data is "
+        warning("Over- or underflow in intermediate calculation. Input data is 
"
               "likely of poor numerical condition.");
         state.status = TERMINATED;
@@ -655,9 +655,9 @@ AnyType logregr_irls_step_final::run(AnyType &args) {
     if (!state.X_transp_AX.is_finite() || !state.X_transp_Az.is_finite()){
         //throw NoSolutionFoundException(
-        //    "Over- or underflow in intermediate calulation. Input data is "
+        //    "Over- or underflow in intermediate calculation. Input data is "
         //    "likely of poor numerical condition.");
         return state;